package net.javajigi.petstore.model;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import net.javajigi.petstore.model.domain.CartItem;
import net.javajigi.petstore.model.domain.Item;
import net.javajigi.petstore.model.domain.Product;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class Cart {
	private Log log = LogFactory.getLog(getClass());

	private Map _details = new HashMap();

	/**
	 * @ejb.interface-method
	 */
	public void addItem(String itemId) {
		addItem(itemId, 1);
	}

	public void addItem(String itemId, int qty) {
		Integer curQty = (Integer) _details.get(itemId);
		if (curQty == null) {
			_details.put(itemId, new Integer(qty));
		} else {
			_details.put(itemId, new Integer(qty + curQty.intValue()));
		}
	}

	public void removeItem(String itemId) {
		_details.remove(itemId);
	}

	public void updateItems(String itemId[], int newQty[]) {
		for (int i = 0; i < itemId.length; i++) {
			String id = itemId[i];
			int qty = newQty[i];

			if (_details.containsKey(id)) {
				if (qty > 0) {
					_details.put(id, new Integer(qty));
				}
			} else {
				log.info(
					" can't update item["
						+ id
						+ "]. This item not in the cart");
			}
		}
	}

	/**
	 * @ejb.interface-method
	 */
	public int getCount() {
		return _details.size();
	}

	/**
	 * @ejb.interface-method
	 */
	public double getTotal() {
		double ret = 0.0d;
		Iterator it = getCartItems().iterator();
		for (; it.hasNext();) {
			CartItem i = (CartItem) it.next();
			ret += (i.getUnitCost() * i.getQuantity());
		}

		return ret;
	}

	/**
	 * @ejb.interface-method
	 */
	public void empty() {
		_details.clear();
	}

	public Map getDetails() {
		return _details;
	}

	public Collection getCartItems() {
		try {
			PetStore petStore = PetStoreImpl.instance();
			ArrayList items = new ArrayList();
			Iterator it = _details.keySet().iterator();
			while (it.hasNext()) {
				String key = (String) it.next();
				Integer value = (Integer) _details.get(key);
				try {
					Item item = petStore.getItem(key);
					Product prod = item.getProduct();

					CartItem ci =
						new CartItem(
							item.getItemId(),
							prod.getProductId(),
							prod.getName(),
							item.getDescription(),
							value.intValue(),
							item.getListPrice());

					items.add(ci);
				} catch (Exception cce) {
					cce.printStackTrace();
				}
			}

			// Sort the items
			Collections.sort(items, new CartItem.ItemIdComparator());
			return items;
		} catch (Exception e) {
			return Collections.EMPTY_LIST;
		}
	}
}
