package net.javajigi.petstore.model;

import java.util.Iterator;
import java.util.Map;

import net.javajigi.petstore.model.domain.Account;
import net.javajigi.petstore.model.domain.Category;
import net.javajigi.petstore.model.domain.Customer;
import net.javajigi.petstore.model.domain.Item;
import net.javajigi.petstore.model.domain.Order;
import net.javajigi.petstore.model.domain.OrderItem;
import net.javajigi.petstore.model.domain.Product;
import net.javajigi.petstore.util.Page;

public class PetStoreImpl implements PetStore {
	private PetStoreImpl() {
	}

	public static PetStoreImpl instance() {
		return new PetStoreImpl();
	}

	public boolean authenticate(String userId, String password)
		throws Exception {
		Account account =
			(Account) getBasePetStoreDAO().retrieve(Account.class, userId);

		if (password.equals(account.getPassword())) {
			return true;
		} else {
			return false;
		}
	}

	public void createCustomer(Customer customer) throws Exception {
		getBasePetStoreDAO().create(customer);
		
		getBasePetStoreDAO().create(customer.getAccount());
	}

	public long createOrder(String userId, String orderDate, Map items)
		throws Exception {
		/* Customer */
		Customer cst = getCustomer(userId);

		/* Order + Items*/
		Order order = new Order(cst);
		order.setOrderDate(orderDate);	

		getBasePetStoreDAO().create(order);		
		
		Iterator it = items.keySet().iterator();

		OrderItem orderItem = null;
		while (it.hasNext()) {
			String itemId = (String) it.next();
			Item item = getItem(itemId);
			Integer quantity = (Integer) items.get(itemId);
			
			orderItem = new OrderItem(item, quantity.intValue());
			orderItem.setOrder(order);
			
			getBasePetStoreDAO().create(orderItem);	
		}
		
		return order.getOrderId();
	}

	public Category getCategory(String categoryId) throws Exception {
		return getPetStoreDAO().findCategory(categoryId);
	}

	public Customer getCustomer(String userId) throws Exception {
		return (Customer) getBasePetStoreDAO().retrieve(Customer.class, userId);
	}

	public Item getItem(String itemId) throws Exception {
		return (Item) getBasePetStoreDAO().retrieve(Item.class, itemId);
	}

	public Order getOrder(int orderId) throws Exception {
		return (Order) getBasePetStoreDAO().retrieve(
			Order.class,
			new Integer(orderId));
	}

	public Product getProduct(String productId) throws Exception {
		return getPetStoreDAO().findProduct(productId);
	}

	public Product getProductByItem(String itemId) throws Exception {
		Item item = getItem(itemId);

		return item.getProduct();
	}

	private PetStoreDAO getPetStoreDAO() {
		PetStoreDAO petStoreDAO = new PetStoreDAO();
		return petStoreDAO;
	}

	private BasePetStoreDAO getBasePetStoreDAO() {
		BasePetStoreDAO basePetStoreDAO = new BasePetStoreDAO();
		return basePetStoreDAO;
	}

	public Page searchProducts(String key, int start, int count) throws Exception {		
		return getPetStoreDAO().searchProduct(key, start, count);
	}

	public void updateCustomer(Customer customer) throws Exception {
		getBasePetStoreDAO().update(customer);
	}
}
