package net.javajigi.petstore.model.domain;

import java.io.Serializable;

/**
 * @hibernate.class
 *         table="T_ORDER_ITEM"
 */
public class OrderItem implements Serializable {
	private Item _item;
	private long _orderItemId;
	private int _quantity;
	private double _unitPrice;
	private Order _order;

	public OrderItem() {
	}

	public OrderItem(Item item, int quantity) {
		_item = item;
		_quantity = quantity;
		_unitPrice = item.getListPrice();
	}

	/**
	 * @return Item
	 *
	 * @hibernate.many-to-one
	 *      column="item_fk"
	 *      cascade="none"
	 */
	public Item getItem() {
		return _item;
	}

	/**
	 * @return Item
	 *
	 * @hibernate.many-to-one
	 *      column="order_fk"
	 *      cascade="all"
	 */
	public Order getOrder() {
		return _order;
	}
	
	public void setOrder(Order order) {
		_order = order;
	}

	/**
	 * @return long
	 *
	 * @hibernate.id
	 *  generator-class="increment"
	 */
	public long getOrderItemId() {
		return _orderItemId;
	}

	/**
	 * @return int
	 *
	 * @hibernate.property
	 */
	public int getQuantity() {
		return _quantity;
	}

	public double getSubTotal() {
		return _quantity * _unitPrice;
	}

	/**
	 * @return double
	 *
	 * @hibernate.property
	 */
	public double getUnitPrice() {
		return _unitPrice;
	}

	/**
	 * Sets the item.
	 * @param item The item to set
	 */
	public void setItem(Item item) {
		_item = item;
	}

	/**
	 * Sets the orderItemUId.
	 * @param orderItemUId The orderItemUId to set
	 */
	public void setOrderItemId(long orderItemUId) {
		_orderItemId = orderItemUId;
	}

	/**
	 * Sets the quantity.
	 * @param quantity The quantity to set
	 */
	public void setQuantity(int quantity) {
		this._quantity = quantity;
	}

	/**
	 * Sets the unitPrice.
	 * @param unitPrice The unitPrice to set
	 */
	public void setUnitPrice(double unitPrice) {
		_unitPrice = unitPrice;
	}
}
